@@ -55,6 +55,7 @@ class DateIntervalFormat;
 
 namespace number {
 class LocalizedNumberFormatter;
+class SimpleNumberFormatter;
 }
 
 /**
@@ -68,7 +69,8 @@ class LocalizedNumberFormatter;
  * getDateInstance(), getDateInstance(), or getDateTimeInstance() rather than
  * explicitly constructing an instance of SimpleDateFormat.  This way, the client
  * is guaranteed to get an appropriate formatting pattern for whatever locale the
- * program is running in.  However, if the client needs something more unusual than
+ * program is running in.  If the client needs more control, they should consider using
+ * DateFormat::createInstanceForSkeleton().  However, if the client needs something more unusual than
  * the default patterns in the locales, he can construct a SimpleDateFormat directly
  * and give it an appropriate pattern (or use one of the factory methods on DateFormat
  * and modify the pattern after the fact with toPattern() and applyPattern().
@@ -76,46 +78,32 @@ class LocalizedNumberFormatter;
  * <p><strong>Date and Time Patterns:</strong></p>
  *
  * <p>Date and time formats are specified by <em>date and time pattern</em> strings.
+ * The full syntax for date and time patterns can be found at
+ * <a href="https://unicode.org/reports/tr35/tr35-dates.html#Date_Format_Patterns">https://unicode.org/reports/tr35/tr35-dates.html#Date_Format_Patterns</a>.
+ *
  * Within date and time pattern strings, all unquoted ASCII letters [A-Za-z] are reserved
- * as pattern letters representing calendar fields. <code>SimpleDateFormat</code> supports
- * the date and time formatting algorithm and pattern letters defined by
- * <a href="http://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table">UTS#35
- * Unicode Locale Data Markup Language (LDML)</a> and further documented for ICU in the
- * <a href="https://sites.google.com/site/icuprojectuserguide/formatparse/datetime?pli=1#TOC-Date-Field-Symbol-Table">ICU
- * User Guide</a>. The following pattern letters are currently available (note that the actual
- * values depend on CLDR and may change from the examples shown here):</p>
+ * as pattern letters representing calendar fields. Some of the most commonly used pattern letters are:</p>
  *
  * <table border="1">
  *     <tr>
- *         <th>Field</th>
  *         <th style="text-align: center">Sym.</th>
  *         <th style="text-align: center">No.</th>
  *         <th>Example</th>
  *         <th>Description</th>
  *     </tr>
  *     <tr>
- *         <th rowspan="3">era</th>
- *         <td style="text-align: center" rowspan="3">G</td>
+ *         <td style="text-align: center">G</td>
  *         <td style="text-align: center">1..3</td>
  *         <td>AD</td>
- *         <td rowspan="3">Era - Replaced with the Era string for the current date. One to three letters for the
+ *         <td>Era - Replaced with the Era string for the current date. One to three letters for the
  *         abbreviated form, four letters for the long (wide) form, five for the narrow form.</td>
  *     </tr>
  *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>Anno Domini</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">5</td>
- *         <td>A</td>
- *     </tr>
- *     <tr>
- *         <th rowspan="6">year</th>
  *         <td style="text-align: center">y</td>
  *         <td style="text-align: center">1..n</td>
  *         <td>1996</td>
  *         <td>Year. Normally the length specifies the padding, but for two letters it also specifies the maximum
- *         length. Example:<div align="center">
+ *         length. Example:<div style="text-align: center">
  *             <center>
  *             <table border="1" cellpadding="2" cellspacing="0">
  *                 <tr>
@@ -171,49 +159,11 @@ class LocalizedNumberFormatter;
  *         </td>
  *     </tr>
  *     <tr>
- *         <td style="text-align: center">Y</td>
- *         <td style="text-align: center">1..n</td>
- *         <td>1997</td>
- *         <td>Year (in "Week of Year" based calendars). Normally the length specifies the padding,
- *         but for two letters it also specifies the maximum length. This year designation is used in ISO
- *         year-week calendar as defined by ISO 8601, but can be used in non-Gregorian based calendar systems
- *         where week date processing is desired. May not always be the same value as calendar year.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">u</td>
- *         <td style="text-align: center">1..n</td>
- *         <td>4601</td>
- *         <td>Extended year. This is a single number designating the year of this calendar system, encompassing
- *         all supra-year fields. For example, for the Julian calendar system, year numbers are positive, with an
- *         era of BCE or CE. An extended year value for the Julian calendar system assigns positive values to CE
- *         years and negative values to BCE years, with 1 BCE being year 0.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center" rowspan="3">U</td>
- *         <td style="text-align: center">1..3</td>
- *         <td>&#30002;&#23376;</td>
- *         <td rowspan="3">Cyclic year name. Calendars such as the Chinese lunar calendar (and related calendars)
- *         and the Hindu calendars use 60-year cycles of year names. Use one through three letters for the abbreviated
- *         name, four for the full (wide) name, or five for the narrow name (currently the data only provides abbreviated names,
- *         which will be used for all requested name widths). If the calendar does not provide cyclic year name data,
- *         or if the year value to be formatted is out of the range of years for which cyclic name data is provided,
- *         then numeric formatting is used (behaves like 'y').</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>(currently also &#30002;&#23376;)</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">5</td>
- *         <td>(currently also &#30002;&#23376;)</td>
- *     </tr>
- *     <tr>
- *         <th rowspan="6">quarter</th>
  *         <td rowspan="3" style="text-align: center">Q</td>
  *         <td style="text-align: center">1..2</td>
  *         <td>02</td>
- *         <td rowspan="3">Quarter - Use one or two for the numerical quarter, three for the abbreviation, or four for the
- *         full (wide) name (five for the narrow name is not yet supported).</td>
+ *         <td rowspan="3">Quarter - Use one or two for the numerical quarter, three for the abbreviation, or four
+ *         for the full (wide) name (five for the narrow name is not yet supported).</td>
  *     </tr>
  *     <tr>
  *         <td style="text-align: center">3</td>
@@ -224,28 +174,12 @@ class LocalizedNumberFormatter;
  *         <td>2nd quarter</td>
  *     </tr>
  *     <tr>
- *         <td rowspan="3" style="text-align: center">q</td>
- *         <td style="text-align: center">1..2</td>
- *         <td>02</td>
- *         <td rowspan="3"><b>Stand-Alone</b> Quarter - Use one or two for the numerical quarter, three for the abbreviation,
- *         or four for the full name (five for the narrow name is not yet supported).</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">3</td>
- *         <td>Q2</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>2nd quarter</td>
- *     </tr>
- *     <tr>
- *         <th rowspan="8">month</th>
  *         <td rowspan="4" style="text-align: center">M</td>
  *         <td style="text-align: center">1..2</td>
  *         <td>09</td>
  *         <td rowspan="4">Month - Use one or two for the numerical month, three for the abbreviation, four for
  *         the full (wide) name, or five for the narrow name. With two ("MM"), the month number is zero-padded
- *         if necessary (e.g. "08")</td>
+ *         if necessary (e.g. "08").</td>
  *     </tr>
  *     <tr>
  *         <td style="text-align: center">3</td>
@@ -260,41 +194,6 @@ class LocalizedNumberFormatter;
  *         <td>S</td>
  *     </tr>
  *     <tr>
- *         <td rowspan="4" style="text-align: center">L</td>
- *         <td style="text-align: center">1..2</td>
- *         <td>09</td>
- *         <td rowspan="4"><b>Stand-Alone</b> Month - Use one or two for the numerical month, three for the abbreviation,
- *         four for the full (wide) name, or 5 for the narrow name. With two ("LL"), the month number is zero-padded if
- *         necessary (e.g. "08")</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">3</td>
- *         <td>Sep</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>September</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">5</td>
- *         <td>S</td>
- *     </tr>
- *     <tr>
- *         <th rowspan="2">week</th>
- *         <td style="text-align: center">w</td>
- *         <td style="text-align: center">1..2</td>
- *         <td>27</td>
- *         <td>Week of Year. Use "w" to show the minimum number of digits, or "ww" to always show two digits
- *         (zero-padding if necessary, e.g. "08").</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">W</td>
- *         <td style="text-align: center">1</td>
- *         <td>3</td>
- *         <td>Week of Month</td>
- *     </tr>
- *     <tr>
- *         <th rowspan="4">day</th>
  *         <td style="text-align: center">d</td>
  *         <td style="text-align: center">1..2</td>
  *         <td>1</td>
@@ -302,29 +201,6 @@ class LocalizedNumberFormatter;
  *         two digits (zero-padding if necessary, e.g. "08").</td>
  *     </tr>
  *     <tr>
- *         <td style="text-align: center">D</td>
- *         <td style="text-align: center">1..3</td>
- *         <td>345</td>
- *         <td>Day of year</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">F</td>
- *         <td style="text-align: center">1</td>
- *         <td>2</td>
- *         <td>Day of Week in Month. The example is for the 2nd Wed in July</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">g</td>
- *         <td style="text-align: center">1..n</td>
- *         <td>2451334</td>
- *         <td>Modified Julian day. This is different from the conventional Julian day number in two regards.
- *         First, it demarcates days at local zone midnight, rather than noon GMT. Second, it is a local number;
- *         that is, it depends on the local time zone. It can be thought of as a single number that encompasses
- *         all the date-related fields.</td>
- *     </tr>
- *     <tr>
- *         <th rowspan="14">week<br>
- *         day</th>
  *         <td rowspan="4" style="text-align: center">E</td>
  *         <td style="text-align: center">1..3</td>
  *         <td>Tue</td>
@@ -344,61 +220,12 @@ class LocalizedNumberFormatter;
  *         <td>Tu</td>
  *     </tr>
  *     <tr>
- *         <td rowspan="5" style="text-align: center">e</td>
- *         <td style="text-align: center">1..2</td>
- *         <td>2</td>
- *         <td rowspan="5">Local day of week. Same as E except adds a numeric value that will depend on the local
- *         starting day of the week, using one or two letters. For this example, Monday is the first day of the week.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">3</td>
- *         <td>Tue</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>Tuesday</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">5</td>
- *         <td>T</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">6</td>
- *         <td>Tu</td>
- *     </tr>
- *     <tr>
- *         <td rowspan="5" style="text-align: center">c</td>
- *         <td style="text-align: center">1</td>
- *         <td>2</td>
- *         <td rowspan="5"><b>Stand-Alone</b> local day of week - Use one letter for the local numeric value (same
- *         as 'e'), three for the short day, four for the full (wide) name, five for the narrow name, or six for
- *         the short name.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">3</td>
- *         <td>Tue</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>Tuesday</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">5</td>
- *         <td>T</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">6</td>
- *         <td>Tu</td>
- *     </tr>
- *     <tr>
- *         <th>period</th>
  *         <td style="text-align: center">a</td>
  *         <td style="text-align: center">1</td>
  *         <td>AM</td>
  *         <td>AM or PM</td>
  *     </tr>
  *     <tr>
- *         <th rowspan="4">hour</th>
  *         <td style="text-align: center">h</td>
  *         <td style="text-align: center">1..2</td>
  *         <td>11</td>
@@ -415,27 +242,13 @@ class LocalizedNumberFormatter;
  *         12-hour-cycle format (h or K). Use HH for zero padding.</td>
  *     </tr>
  *     <tr>
- *         <td style="text-align: center">K</td>
- *         <td style="text-align: center">1..2</td>
- *         <td>0</td>
- *         <td>Hour [0-11]. When used in a skeleton, only matches K or h, see above. Use KK for zero padding.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">k</td>
- *         <td style="text-align: center">1..2</td>
- *         <td>24</td>
- *         <td>Hour [1-24]. When used in a skeleton, only matches k or H, see above. Use kk for zero padding.</td>
- *     </tr>
- *     <tr>
- *         <th>minute</th>
  *         <td style="text-align: center">m</td>
  *         <td style="text-align: center">1..2</td>
  *         <td>59</td>
  *         <td>Minute. Use "m" to show the minimum number of digits, or "mm" to always show two digits
- *         (zero-padding if necessary, e.g. "08").</td>
+ *         (zero-padding if necessary, e.g. "08")..</td>
  *     </tr>
  *     <tr>
- *         <th rowspan="3">second</th>
  *         <td style="text-align: center">s</td>
  *         <td style="text-align: center">1..2</td>
  *         <td>12</td>
@@ -443,28 +256,10 @@ class LocalizedNumberFormatter;
  *         (zero-padding if necessary, e.g. "08").</td>
  *     </tr>
  *     <tr>
- *         <td style="text-align: center">S</td>
- *         <td style="text-align: center">1..n</td>
- *         <td>3450</td>
- *         <td>Fractional Second - truncates (like other time fields) to the count of letters when formatting.
- *         Appends zeros if more than 3 letters specified. Truncates at three significant digits when parsing.
- *         (example shows display using pattern SSSS for seconds value 12.34567)</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">A</td>
- *         <td style="text-align: center">1..n</td>
- *         <td>69540000</td>
- *         <td>Milliseconds in day. This field behaves <i>exactly</i> like a composite of all time-related fields,
- *         not including the zone fields. As such, it also reflects discontinuities of those fields on DST transition
- *         days. On a day of DST onset, it will jump forward. On a day of DST cessation, it will jump backward. This
- *         reflects the fact that is must be combined with the offset field to obtain a unique local time value.</td>
- *     </tr>
- *     <tr>
- *         <th rowspan="23">zone</th>
  *         <td rowspan="2" style="text-align: center">z</td>
  *         <td style="text-align: center">1..3</td>
  *         <td>PDT</td>
- *         <td>The <i>short specific non-location format</i>.
+ *         <td>Time zone.  The <i>short specific non-location format</i>.
  *         Where that is unavailable, falls back to the <i>short localized GMT format</i> ("O").</td>
  *     </tr>
  *     <tr>
@@ -474,43 +269,10 @@ class LocalizedNumberFormatter;
  *         Where that is unavailable, falls back to the <i>long localized GMT format</i> ("OOOO").</td>
  *     </tr>
  *     <tr>
- *         <td rowspan="3" style="text-align: center">Z</td>
- *         <td style="text-align: center">1..3</td>
- *         <td>-0800</td>
- *         <td>The <i>ISO8601 basic format</i> with hours, minutes and optional seconds fields.
- *         The format is equivalent to RFC 822 zone format (when optional seconds field is absent).
- *         This is equivalent to the "xxxx" specifier.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>GMT-8:00</td>
- *         <td>The <i>long localized GMT format</i>.
- *         This is equivalent to the "OOOO" specifier.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">5</td>
- *         <td>-08:00<br>
- *         -07:52:58</td>
- *         <td>The <i>ISO8601 extended format</i> with hours, minutes and optional seconds fields.
- *         The ISO8601 UTC indicator "Z" is used when local time offset is 0.
- *         This is equivalent to the "XXXXX" specifier.</td>
- *     </tr>
- *     <tr>
- *         <td rowspan="2" style="text-align: center">O</td>
- *         <td style="text-align: center">1</td>
- *         <td>GMT-8</td>
- *         <td>The <i>short localized GMT format</i>.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>GMT-08:00</td>
- *         <td>The <i>long localized GMT format</i>.</td>
- *     </tr>
- *     <tr>
  *         <td rowspan="2" style="text-align: center">v</td>
  *         <td style="text-align: center">1</td>
  *         <td>PT</td>
- *         <td>The <i>short generic non-location format</i>.
+ *         <td>Time zone. The <i>short generic non-location format</i>.
  *         Where that is unavailable, falls back to the <i>generic location format</i> ("VVVV"),
  *         then the <i>short localized GMT format</i> as the final fallback.</td>
  *     </tr>
@@ -520,109 +282,6 @@ class LocalizedNumberFormatter;
  *         <td>The <i>long generic non-location format</i>.
  *         Where that is unavailable, falls back to <i>generic location format</i> ("VVVV").
  *     </tr>
- *     <tr>
- *         <td rowspan="4" style="text-align: center">V</td>
- *         <td style="text-align: center">1</td>
- *         <td>uslax</td>
- *         <td>The short time zone ID.
- *         Where that is unavailable, the special short time zone ID <i>unk</i> (Unknown Zone) is used.<br>
- *         <i><b>Note</b>: This specifier was originally used for a variant of the short specific non-location format,
- *         but it was deprecated in the later version of the LDML specification. In CLDR 23/ICU 51, the definition of
- *         the specifier was changed to designate a short time zone ID.</i></td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">2</td>
- *         <td>America/Los_Angeles</td>
- *         <td>The long time zone ID.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">3</td>
- *         <td>Los Angeles</td>
- *         <td>The exemplar city (location) for the time zone.
- *         Where that is unavailable, the localized exemplar city name for the special zone <i>Etc/Unknown</i> is used
- *         as the fallback (for example, "Unknown City"). </td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>Los Angeles Time</td>
- *         <td>The <i>generic location format</i>.
- *         Where that is unavailable, falls back to the <i>long localized GMT format</i> ("OOOO";
- *         Note: Fallback is only necessary with a GMT-style Time Zone ID, like Etc/GMT-830.)<br>
- *         This is especially useful when presenting possible timezone choices for user selection,
- *         since the naming is more uniform than the "v" format.</td>
- *     </tr>
- *     <tr>
- *         <td rowspan="5" style="text-align: center">X</td>
- *         <td style="text-align: center">1</td>
- *         <td>-08<br>
- *         +0530<br>
- *         Z</td>
- *         <td>The <i>ISO8601 basic format</i> with hours field and optional minutes field.
- *         The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">2</td>
- *         <td>-0800<br>
- *         Z</td>
- *         <td>The <i>ISO8601 basic format</i> with hours and minutes fields.
- *         The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">3</td>
- *         <td>-08:00<br>
- *         Z</td>
- *         <td>The <i>ISO8601 extended format</i> with hours and minutes fields.
- *         The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>-0800<br>
- *         -075258<br>
- *         Z</td>
- *         <td>The <i>ISO8601 basic format</i> with hours, minutes and optional seconds fields.
- *         (Note: The seconds field is not supported by the ISO8601 specification.)
- *         The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">5</td>
- *         <td>-08:00<br>
- *         -07:52:58<br>
- *         Z</td>
- *         <td>The <i>ISO8601 extended format</i> with hours, minutes and optional seconds fields.
- *         (Note: The seconds field is not supported by the ISO8601 specification.)
- *         The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
- *     </tr>
- *     <tr>
- *         <td rowspan="5" style="text-align: center">x</td>
- *         <td style="text-align: center">1</td>
- *         <td>-08<br>
- *         +0530</td>
- *         <td>The <i>ISO8601 basic format</i> with hours field and optional minutes field.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">2</td>
- *         <td>-0800</td>
- *         <td>The <i>ISO8601 basic format</i> with hours and minutes fields.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">3</td>
- *         <td>-08:00</td>
- *         <td>The <i>ISO8601 extended format</i> with hours and minutes fields.</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">4</td>
- *         <td>-0800<br>
- *         -075258</td>
- *         <td>The <i>ISO8601 basic format</i> with hours, minutes and optional seconds fields.
- *         (Note: The seconds field is not supported by the ISO8601 specification.)</td>
- *     </tr>
- *     <tr>
- *         <td style="text-align: center">5</td>
- *         <td>-08:00<br>
- *         -07:52:58</td>
- *         <td>The <i>ISO8601 extended format</i> with hours, minutes and optional seconds fields.
- *         (Note: The seconds field is not supported by the ISO8601 specification.)</td>
- *     </tr>
  * </table>
  *
  * <P>
@@ -756,7 +415,7 @@ public:
      * names of the months), but not to provide the pattern.
      * <P>
      * A numbering system override is a string containing either the name of a known numbering system,
-     * or a set of field and numbering system pairs that specify which fields are to be formattied with
+     * or a set of field and numbering system pairs that specify which fields are to be formatted with
      * the alternate numbering system.  For example, to specify that all numeric fields in the specified
      * date or time pattern are to be rendered using Thai digits, simply specify the numbering system override
      * as "thai".  To specify that just the year portion of the date be formatted using Hebrew numbering,
@@ -797,7 +456,7 @@ public:
      * names of the months), but not to provide the pattern.
      * <P>
      * A numbering system override is a string containing either the name of a known numbering system,
-     * or a set of field and numbering system pairs that specify which fields are to be formattied with
+     * or a set of field and numbering system pairs that specify which fields are to be formatted with
      * the alternate numbering system.  For example, to specify that all numeric fields in the specified
      * date or time pattern are to be rendered using Thai digits, simply specify the numbering system override
      * as "thai".  To specify that just the year portion of the date be formatted using Hebrew numbering,
@@ -867,7 +526,7 @@ public:
      * @return    A copy of the object.
      * @stable ICU 2.0
      */
-    virtual SimpleDateFormat* clone() const;
+    virtual SimpleDateFormat* clone() const override;
 
     /**
      * Return true if the given Format objects are semantically equal. Objects
@@ -876,7 +535,7 @@ public:
      * @return         true if the given Format objects are semantically equal.
      * @stable ICU 2.0
      */
-    virtual UBool operator==(const Format& other) const;
+    virtual bool operator==(const Format& other) const override;
 
 
     using DateFormat::format;
@@ -899,7 +558,7 @@ public:
      */
     virtual UnicodeString& format(  Calendar& cal,
                                     UnicodeString& appendTo,
-                                    FieldPosition& pos) const;
+                                    FieldPosition& pos) const override;
 
     /**
      * Format a date or time, which is the standard millis since 24:00 GMT, Jan
@@ -922,7 +581,7 @@ public:
     virtual UnicodeString& format(  Calendar& cal,
                                     UnicodeString& appendTo,
                                     FieldPositionIterator* posIter,
-                                    UErrorCode& status) const;
+                                    UErrorCode& status) const override;
 
     using DateFormat::parse;
 
@@ -954,7 +613,7 @@ public:
      */
     virtual void parse( const UnicodeString& text,
                         Calendar& cal,
-                        ParsePosition& pos) const;
+                        ParsePosition& pos) const override;
 
 
     /**
@@ -1056,7 +715,7 @@ public:
      * with this date-time formatter.
      * @stable ICU 2.0
      */
-    virtual const DateFormatSymbols* getDateFormatSymbols(void) const;
+    virtual const DateFormatSymbols* getDateFormatSymbols() const;
 
     /**
      * Set the date/time formatting symbols.  The caller no longer owns the
@@ -1084,7 +743,7 @@ public:
      * @return          The class ID for all objects of this class.
      * @stable ICU 2.0
      */
-    static UClassID U_EXPORT2 getStaticClassID(void);
+    static UClassID U_EXPORT2 getStaticClassID();
 
     /**
      * Returns a unique class ID POLYMORPHICALLY. Pure virtual override. This
@@ -1097,7 +756,7 @@ public:
      *                  other classes have different class IDs.
      * @stable ICU 2.0
      */
-    virtual UClassID getDynamicClassID(void) const;
+    virtual UClassID getDynamicClassID() const override;
 
     /**
      * Set the calendar to be used by this date format. Initially, the default
@@ -1108,7 +767,7 @@ public:
      * @param calendarToAdopt    Calendar object to be adopted.
      * @stable ICU 2.0
      */
-    virtual void adoptCalendar(Calendar* calendarToAdopt);
+    virtual void adoptCalendar(Calendar* calendarToAdopt) override;
 
     /* Cannot use #ifndef U_HIDE_INTERNAL_API for the following methods since they are virtual */
     /**
@@ -1132,7 +791,7 @@ public:
      * @return the time zone format associated with this date/time formatter.
      * @internal ICU 49 technology preview
      */
-    virtual const TimeZoneFormat* getTimeZoneFormat(void) const;
+    virtual const TimeZoneFormat* getTimeZoneFormat() const;
 
     /**
      * Set a particular UDisplayContext value in the formatter, such as
@@ -1144,7 +803,7 @@ public:
      *               updated with any new status from the function.
      * @stable ICU 53
      */
-    virtual void setContext(UDisplayContext value, UErrorCode& status);
+    virtual void setContext(UDisplayContext value, UErrorCode& status) override;
 
     /**
      * Overrides base class method and
@@ -1153,7 +812,7 @@ public:
      * @param formatToAdopt the NumbeferFormat used
      * @stable ICU 54
      */
-    void adoptNumberFormat(NumberFormat *formatToAdopt);
+    void adoptNumberFormat(NumberFormat *formatToAdopt) override;
 
     /**
      * Allow the user to set the NumberFormat for several fields
@@ -1183,11 +842,11 @@ public:
     /**
      * This is for ICU internal use only. Please do not use.
      * Check whether the 'field' is smaller than all the fields covered in
-     * pattern, return TRUE if it is. The sequence of calendar field,
+     * pattern, return true if it is. The sequence of calendar field,
      * from large to small is: ERA, YEAR, MONTH, DATE, AM_PM, HOUR, MINUTE,...
      * @param field    the calendar field need to check against
-     * @return         TRUE if the 'field' is smaller than all the fields
-     *                 covered in pattern. FALSE otherwise.
+     * @return         true if the 'field' is smaller than all the fields
+     *                 covered in pattern. false otherwise.
      * @internal ICU 4.0
      */
     UBool isFieldUnitIgnored(UCalendarDateFields field) const;
@@ -1196,12 +855,12 @@ public:
     /**
      * This is for ICU internal use only. Please do not use.
      * Check whether the 'field' is smaller than all the fields covered in
-     * pattern, return TRUE if it is. The sequence of calendar field,
+     * pattern, return true if it is. The sequence of calendar field,
      * from large to small is: ERA, YEAR, MONTH, DATE, AM_PM, HOUR, MINUTE,...
      * @param pattern  the pattern to check against
      * @param field    the calendar field need to check against
-     * @return         TRUE if the 'field' is smaller than all the fields
-     *                 covered in pattern. FALSE otherwise.
+     * @return         true if the 'field' is smaller than all the fields
+     *                 covered in pattern. false otherwise.
      * @internal ICU 4.0
      */
     static UBool isFieldUnitIgnored(const UnicodeString& pattern,
@@ -1215,18 +874,18 @@ public:
      * @return   locale in this simple date formatter
      * @internal ICU 4.0
      */
-    const Locale& getSmpFmtLocale(void) const;
+    const Locale& getSmpFmtLocale() const;
 #endif  /* U_HIDE_INTERNAL_API */
 
 private:
     friend class DateFormat;
     friend class DateIntervalFormat;
 
-    void initializeDefaultCentury(void);
+    void initializeDefaultCentury();
 
-    void initializeBooleanAttributes(void);
+    void initializeBooleanAttributes();
 
-    SimpleDateFormat(); // default constructor not implemented
+    SimpleDateFormat() = delete; // default constructor not implemented
 
     /**
      * Used by the DateFormat factory methods to construct a SimpleDateFormat.
@@ -1274,6 +933,7 @@ private:
                    int32_t count,
                    UDisplayContext capitalizationContext,
                    int32_t fieldNum,
+                   char16_t fieldToOutput,
                    FieldPositionHandler& handler,
                    Calendar& cal,
                    UErrorCode& status) const; // in case of illegal argument
@@ -1298,24 +958,24 @@ private:
                            int32_t maxDigits) const;
 
     /**
-     * Return true if the given format character, occuring count
+     * Return true if the given format character, occurring count
      * times, represents a numeric field.
      */
     static UBool isNumeric(char16_t formatChar, int32_t count);
 
     /**
-     * Returns TRUE if the patternOffset is at the start of a numeric field.
+     * Returns true if the patternOffset is at the start of a numeric field.
      */
     static UBool isAtNumericField(const UnicodeString &pattern, int32_t patternOffset);
 
     /**
-     * Returns TRUE if the patternOffset is right after a non-numeric field.
+     * Returns true if the patternOffset is right after a non-numeric field.
      */
     static UBool isAfterNonNumericField(const UnicodeString &pattern, int32_t patternOffset);
 
     /**
      * initializes fCalendar from parameters.  Returns fCalendar as a convenience.
-     * @param adoptZone  Zone to be adopted, or NULL for TimeZone::createDefault().
+     * @param adoptZone  Zone to be adopted, or nullptr for TimeZone::createDefault().
      * @param locale Locale of the calendar
      * @param status Error code
      * @return the newly constructed fCalendar
@@ -1348,7 +1008,7 @@ private:
      * @param field the date field being parsed.
      * @param stringArray the string array to parsed.
      * @param stringArrayCount the size of the array.
-     * @param monthPattern pointer to leap month pattern, or NULL if none.
+     * @param monthPattern pointer to leap month pattern, or nullptr if none.
      * @param cal a Calendar set to the date and time to be formatted
      *            into a date/time string.
      * @return the new start position if matching succeeded; a negative number
@@ -1358,6 +1018,22 @@ private:
                         const UnicodeString* stringArray, int32_t stringArrayCount,
                         const UnicodeString* monthPattern, Calendar& cal) const;
 
+    /**
+     * Private code-size reduction function used by subParse. Only for UCAL_MONTH
+     * @param text the time text being parsed.
+     * @param start where to start parsing.
+     * @param wideStringArray the wide string array to parsed.
+     * @param shortStringArray the short string array to parsed.
+     * @param stringArrayCount the size of the string arrays.
+     * @param cal a Calendar set to the date and time to be formatted
+     *            into a date/time string.
+     * @return the new start position if matching succeeded; a negative number
+     * indicating matching failure, otherwise.
+     */
+    int32_t matchAlphaMonthStrings(const UnicodeString& text, int32_t start,
+                        const UnicodeString* wideStringArray, const UnicodeString* shortStringArray,
+                        int32_t stringArrayCount, Calendar& cal) const;
+
     /**
      * Private code-size reduction function used by subParse.
      * @param text the time text being parsed.
@@ -1385,15 +1061,15 @@ private:
      *
      * @param pattern the pattern string
      * @param patternOffset the starting offset into the pattern text. On
-     *        outupt will be set the offset of the first non-literal character in the pattern
+     *        output will be set the offset of the first non-literal character in the pattern
      * @param text the text being parsed
      * @param textOffset the starting offset into the text. On output
      *                   will be set to the offset of the character after the match
-     * @param whitespaceLenient <code>TRUE</code> if whitespace parse is lenient, <code>FALSE</code> otherwise.
-     * @param partialMatchLenient <code>TRUE</code> if partial match parse is lenient, <code>FALSE</code> otherwise.
-     * @param oldLeniency <code>TRUE</code> if old leniency control is lenient, <code>FALSE</code> otherwise.
+     * @param whitespaceLenient <code>true</code> if whitespace parse is lenient, <code>false</code> otherwise.
+     * @param partialMatchLenient <code>true</code> if partial match parse is lenient, <code>false</code> otherwise.
+     * @param oldLeniency <code>true</code> if old leniency control is lenient, <code>false</code> otherwise.
      *
-     * @return <code>TRUE</code> if the literal text could be matched, <code>FALSE</code> otherwise.
+     * @return <code>true</code> if the literal text could be matched, <code>false</code> otherwise.
      */
     static UBool matchLiterals(const UnicodeString &pattern, int32_t &patternOffset,
                                const UnicodeString &text, int32_t &textOffset,
@@ -1415,14 +1091,14 @@ private:
      * @param patLoc
      * @param numericLeapMonthFormatter If non-null, used to parse numeric leap months.
      * @param tzTimeType the type of parsed time zone - standard, daylight or unknown (output).
-     *      This parameter can be NULL if caller does not need the information.
+     *      This parameter can be nullptr if caller does not need the information.
      * @return the new start position if matching succeeded; a negative number
      * indicating matching failure, otherwise.
      */
     int32_t subParse(const UnicodeString& text, int32_t& start, char16_t ch, int32_t count,
                      UBool obeyCount, UBool allowNegative, UBool ambiguousYear[], int32_t& saveHebrewMonth, Calendar& cal,
                      int32_t patLoc, MessageFormat * numericLeapMonthFormatter, UTimeZoneFormatTimeType *tzTimeType,
-                     int32_t *dayPeriod=NULL) const;
+                     int32_t *dayPeriod=nullptr) const;
 
     void parseInt(const UnicodeString& text,
                   Formattable& number,
@@ -1503,14 +1179,9 @@ private:
     int32_t skipUWhiteSpace(const UnicodeString& text, int32_t pos) const;
 
     /**
-     * Initialize LocalizedNumberFormatter instances used for speedup.
+     * Initialize SimpleNumberFormat instance
      */
-    void initFastNumberFormatters(UErrorCode& status);
-
-    /**
-     * Delete the LocalizedNumberFormatter instances used for speedup.
-     */
-    void freeFastNumberFormatters();
+    void initSimpleNumberFormatter(UErrorCode &status);
 
     /**
      * Initialize NumberFormat instances used for numbering system overrides.
@@ -1582,12 +1253,12 @@ private:
      * A pointer to an object containing the strings to use in formatting (e.g.,
      * month and day names, AM and PM strings, time zone names, etc.)
      */
-    DateFormatSymbols*  fSymbols;   // Owned
+    DateFormatSymbols*  fSymbols = nullptr;   // Owned
 
     /**
      * The time zone formatter
      */
-    TimeZoneFormat* fTimeZoneFormat;
+    TimeZoneFormat* fTimeZoneFormat = nullptr;
 
     /**
      * If dates have ambiguous years, we map them into the century starting
@@ -1618,34 +1289,29 @@ private:
         int32_t hash;
         NSOverride *next;
         void free();
-        NSOverride() : snf(NULL), hash(0), next(NULL) {
+        NSOverride() : snf(nullptr), hash(0), next(nullptr) {
         }
         ~NSOverride();
     };
 
     /**
-     * The number format in use for each date field. NULL means fall back
+     * The number format in use for each date field. nullptr means fall back
      * to fNumberFormat in DateFormat.
      */
-    const SharedNumberFormat    **fSharedNumberFormatters;
-
-    enum NumberFormatterKey {
-        SMPDTFMT_NF_1x10,
-        SMPDTFMT_NF_2x10,
-        SMPDTFMT_NF_3x10,
-        SMPDTFMT_NF_4x10,
-        SMPDTFMT_NF_2x2,
-        SMPDTFMT_NF_COUNT
-    };
+    const SharedNumberFormat    **fSharedNumberFormatters = nullptr;
 
     /**
-     * Number formatters pre-allocated for fast performance on the most common integer lengths.
+     * Number formatter pre-allocated for fast performance
+     * 
+     * This references the decimal symbols from fNumberFormatter if it is an instance
+     * of DecimalFormat (and is otherwise null). This should always be cleaned up before
+     * destroying fNumberFormatter.
      */
-    const number::LocalizedNumberFormatter* fFastNumberFormatters[SMPDTFMT_NF_COUNT] = {};
+    const number::SimpleNumberFormatter* fSimpleNumberFormatter = nullptr;
 
     UBool fHaveDefaultCentury;
 
-    const BreakIterator* fCapitalizationBrkIter;
+    const BreakIterator* fCapitalizationBrkIter = nullptr;
 };
 
 inline UDate
