@@ -46,6 +46,7 @@
 #include "ucol_imp.h"
 #include "ucol_swp.h"
 #include "ucnv_bld.h"
+#include "udataswp.h"
 #include "sprpimpl.h"
 #include "rbbidata.h"
 
@@ -117,7 +118,7 @@ static void lots_of_mallocs()
 #endif
 
 #if !UCONFIG_NO_FILE_IO && !UCONFIG_NO_LEGACY_CONVERSION
-static void TestUDataOpen(){
+static void TestUDataOpen(void){
     UDataMemory *result;
     UErrorCode status=U_ZERO_ERROR;
     const char* memMap[][2]={
@@ -442,7 +443,7 @@ static const ICU_COMMON_Data_Header gEmptyHeader = {
 };
 
 
-static void TestUDataSetAppData(){
+static void TestUDataSetAppData(void){
 /*    UDataMemory      *dataItem;*/
 
     UErrorCode        status=U_ZERO_ERROR;
@@ -497,7 +498,7 @@ static void TestUDataSetAppData(){
         dataItem = udata_open("appData1", "res", "te_IN", &status); **/
 }
 
-static char *safeGetICUDataDirectory() {
+static char *safeGetICUDataDirectory(void) {
     const char *dataDir = u_getDataDirectory();  /* Returned string vanashes with u_cleanup */
     char *retStr = NULL;
     if (dataDir != NULL) {
@@ -507,7 +508,7 @@ static char *safeGetICUDataDirectory() {
     return retStr;
 }
     
-static void TestUDataFileAccess(){
+static void TestUDataFileAccess(void){
     UErrorCode status;
     char            *icuDataDir;
     icuDataDir = safeGetICUDataDirectory();   /* save icu data dir, so we can put it back
@@ -644,7 +645,7 @@ isAcceptable3(void *context,
 }
 
 #if !UCONFIG_NO_FILE_IO && !UCONFIG_NO_LEGACY_CONVERSION
-static void TestUDataOpenChoiceDemo1() {
+static void TestUDataOpenChoiceDemo1(void) {
     UDataMemory *result;
     UErrorCode status=U_ZERO_ERROR;
 
@@ -744,7 +745,7 @@ isAcceptable(void *context,
 
 /* This test checks to see if the isAcceptable function is being called correctly. */
 
-static void TestUDataOpenChoiceDemo2() {
+static void TestUDataOpenChoiceDemo2(void) {
     UDataMemory *result;
     UErrorCode status=U_ZERO_ERROR;
     int i;
@@ -791,7 +792,7 @@ static void TestUDataOpenChoiceDemo2() {
     }
 }
 
-static void TestUDataGetInfo() {
+static void TestUDataGetInfo(void) {
 
     UDataMemory *result;
     /* UDataInfo cf. udata.h */
@@ -868,7 +869,7 @@ static void TestUDataGetInfo() {
     udata_close(result);
 }
 
-static void TestUDataGetMemory() {
+static void TestUDataGetMemory(void) {
 
     UDataMemory *result;
     const int32_t *table=NULL;
@@ -916,7 +917,7 @@ static void TestUDataGetMemory() {
 
 }
 
-static void TestErrorConditions(){
+static void TestErrorConditions(void){
 
     UDataMemory *result=NULL;
     UErrorCode status=U_ZERO_ERROR;
@@ -1033,7 +1034,7 @@ static void TestErrorConditions(){
 }
 
 /* Test whether apps and ICU can each have their own root.res */
-static void TestAppData()
+static void TestAppData(void)
 {
     UResourceBundle *icu, *app;
     UResourceBundle *tmp = NULL;
@@ -1121,7 +1122,7 @@ static void TestAppData()
 }
 #endif
 
-static void TestICUDataName()
+static void TestICUDataName(void)
 {
     UVersionInfo icuVersion;
     char expectDataName[20];
@@ -1138,18 +1139,7 @@ static void TestICUDataName()
     switch(U_CHARSET_FAMILY)
     {
     case U_ASCII_FAMILY:
-          switch((int)U_IS_BIG_ENDIAN)
-          {
-          case 1:
-                typeChar = 'b';
-                break;
-          case 0:
-                typeChar = 'l';
-                break;
-          default:
-                log_err("Expected 1 or 0 for U_IS_BIG_ENDIAN, got %d!\n", (int)U_IS_BIG_ENDIAN);
-                /* return; */
-          }
+          typeChar = U_IS_BIG_ENDIAN ? 'b' : 'l';
           break;
     case U_EBCDIC_FAMILY:
         typeChar = 'e';
@@ -1333,7 +1323,7 @@ static const struct {
     /* EUC-TW (3-byte) conversion table file without extension */
     {"ibm-964_P110-1999",        "cnv", ucnv_swap},
     /* GB 18030 (4-byte) conversion table file without extension */
-    {"gb18030",                  "cnv", ucnv_swap},
+    {"gb18030-2022",             "cnv", ucnv_swap},
     /* MBCS conversion table file with extension */
     {"*test4x",                  "cnv", ucnv_swap},
     /*
@@ -1631,7 +1621,7 @@ printErrorToString(void *context, const char *fmt, va_list args) {
 
 #if !UCONFIG_NO_FILE_IO && !UCONFIG_NO_LEGACY_CONVERSION
 static void
-TestSwapData() {
+TestSwapData(void) {
     char name[100];
     UDataSwapper *ds;
     UDataMemory *pData;
@@ -1747,7 +1737,7 @@ TestSwapData() {
 }
 #endif
 
-static void PointerTableOfContents() {
+static void PointerTableOfContents(void) {
     UDataMemory      *dataItem;
     UErrorCode        status=U_ZERO_ERROR;
        
