@@ -42,7 +42,7 @@ class AffixUtilsTest : public IntlTest {
     void testInvalid();
     void testUnescapeWithSymbolProvider();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 
   private:
     UnicodeString unescapeWithDefaults(const SymbolProvider &defaultProvider, UnicodeString input,
@@ -103,9 +103,11 @@ class NumberFormatterApiTest : public IntlTestWithFieldPosition {
     void toDecimalNumber();
     void microPropsInternals();
     void formatUnitsAliases();
+    void formatArbitraryConstant();
+    void TestPortionFormat();
     void testIssue22378();
-    
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 
   private:
     CurrencyUnit USD;
@@ -213,7 +215,7 @@ class DecimalQuantityTest : public IntlTest {
     void testSuppressedExponentUnchangedByInitialScaling();
     void testDecimalQuantityParseFormatRoundTrip();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 
   private:
     void assertDoubleEquals(UnicodeString message, double a, double b);
@@ -226,7 +228,7 @@ class DoubleConversionTest : public IntlTest {
   public:
     void testDoubleConversionApi();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 };
 
 class ModifiersTest : public IntlTest {
@@ -236,7 +238,7 @@ class ModifiersTest : public IntlTest {
     void testSimpleModifier();
     void testCurrencySpacingEnabledModifier();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 
   private:
     void assertModifierEquals(const Modifier &mod, int32_t expectedPrefixLength, bool expectedStrong,
@@ -254,7 +256,7 @@ class PatternModifierTest : public IntlTest {
     void testPatternWithNoPlaceholder();
     void testMutableEqualsImmutable();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 
   private:
     UnicodeString getPrefix(const MutablePatternModifier &mod, UErrorCode &status);
@@ -269,7 +271,7 @@ class PatternStringTest : public IntlTestWithFieldPosition {
     void testBug13117();
     void testCurrencyDecimal();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 
   private:
 };
@@ -286,7 +288,7 @@ class NumberParserTest : public IntlTest {
     void test20360_BidiOverflow();
     void testInfiniteRecursion();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 };
 
 class NumberSkeletonTest : public IntlTest {
@@ -302,8 +304,9 @@ class NumberSkeletonTest : public IntlTest {
     void wildcardCharacters();
     void perUnitInArabic();
     void perUnitToSkeleton();
+    void measurementSystemOverride();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 
   private:
     void expectedErrorSkeleton(const char16_t** cases, int32_t casesLen);
@@ -324,13 +327,15 @@ class NumberRangeFormatterTest : public IntlTestWithFieldPosition {
     void testFieldPositions();
     void testCopyMove();
     void toObject();
+    void locale();
     void testGetDecimalNumbers();
     void test21684_Performance();
     void test21358_SignPosition();
     void test21683_StateLeak();
     void testCreateLNRFFromNumberingSystemInSkeleton();
+    void test22288_DifferentStartEndSettings();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 
   private:
     CurrencyUnit USD;
@@ -370,19 +375,20 @@ class SimpleNumberFormatterTest : public IntlTestWithFieldPosition {
   public:
     void testBasic();
     void testWithOptions();
+    void testDigits();
     void testSymbols();
     void testSign();
     void testCopyMove();
     void testCAPI();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 };
 
 class NumberPermutationTest : public IntlTest {
   public:
     void testPermutations();
 
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override;
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override;
 };
 
 
@@ -400,7 +406,7 @@ class NumberPermutationTest : public IntlTest {
 
 class NumberTest : public IntlTest {
   public:
-    void runIndexedTest(int32_t index, UBool exec, const char *&name, char *par = 0) override {
+    void runIndexedTest(int32_t index, UBool exec, const char*& name, char* par = nullptr) override {
         if (exec) {
             logln("TestSuite NumberTest: ");
         }
