@@ -87,6 +87,9 @@ TimeZoneFormatTest::runIndexedTest( int32_t index, UBool exec, const char* &name
         TESTCASE(7, TestFormatTZDBNamesAllZoneCoverage);
         TESTCASE(8, TestAdoptDefaultThreadSafe);
         TESTCASE(9, TestCentralTime);
+        TESTCASE(10, TestBogusLocale);
+        TESTCASE(11, Test22614GetMetaZoneNamesNotCrash);
+        TESTCASE(12, Test22615NonASCIIID);
     default: name = ""; break;
     }
 }
@@ -108,7 +111,7 @@ TimeZoneFormatTest::TestTimeZoneRoundTrip() {
         {1960, 6, 15},
     };
 
-    Calendar *cal = Calendar::createInstance(TimeZone::createTimeZone((UnicodeString)"UTC"), status);
+    Calendar* cal = Calendar::createInstance(TimeZone::createTimeZone(UnicodeString("UTC")), status);
     if (U_FAILURE(status)) {
         dataerrln("Calendar::createInstance failed: %s", u_errorName(status));
         return;
@@ -178,9 +181,9 @@ TimeZoneFormatTest::TestTimeZoneRoundTrip() {
         gmtFmt.format(0.0, localGMTString);
 
         for (int32_t patidx = 0; patidx < UPRV_LENGTHOF(PATTERNS); patidx++) {
-            SimpleDateFormat *sdf = new SimpleDateFormat((UnicodeString)PATTERNS[patidx], LOCALES[locidx], status);
+            SimpleDateFormat* sdf = new SimpleDateFormat(UnicodeString(PATTERNS[patidx]), LOCALES[locidx], status);
             if (U_FAILURE(status)) {
-                dataerrln((UnicodeString)"new SimpleDateFormat failed for pattern " +
+                dataerrln(UnicodeString("new SimpleDateFormat failed for pattern ") +
                     PATTERNS[patidx] + " for locale " + LOCALES[locidx].getName() + " - " + u_errorName(status));
                 status = U_ZERO_ERROR;
                 continue;
@@ -223,12 +226,12 @@ TimeZoneFormatTest::TestTimeZoneRoundTrip() {
 
                     tz->getOffset(DATES[datidx], false, inRaw, inDst, status);
                     if (U_FAILURE(status)) {
-                        errln((UnicodeString)"Failed to get offsets from time zone" + *tzid);
+                        errln(UnicodeString("Failed to get offsets from time zone") + *tzid);
                         status = U_ZERO_ERROR;
                     }
                     outtz.getOffset(DATES[datidx], false, outRaw, outDst, status);
                     if (U_FAILURE(status)) {
-                        errln((UnicodeString)"Failed to get offsets from time zone" + outtzid);
+                        errln(UnicodeString("Failed to get offsets from time zone") + outtzid);
                         status = U_ZERO_ERROR;
                     }
 
@@ -238,18 +241,18 @@ TimeZoneFormatTest::TestTimeZoneRoundTrip() {
                         TimeZone::getCanonicalID(*tzid, canonicalID, status);
                         if (U_FAILURE(status)) {
                             // Unknown ID - we should not get here
-                            errln((UnicodeString)"Unknown ID " + *tzid);
+                            errln(UnicodeString("Unknown ID ") + *tzid);
                             status = U_ZERO_ERROR;
                         } else if (outtzid != canonicalID) {
                             if (outtzid.compare(ETC_UNKNOWN, -1) == 0) {
                                 // Note that some zones like Asia/Riyadh87 does not have
                                 // short zone ID and "unk" is used as fallback
-                                logln((UnicodeString)"Canonical round trip failed (probably as expected); tz=" + *tzid
+                                logln(UnicodeString("Canonical round trip failed (probably as expected); tz=") + *tzid
                                         + ", locale=" + LOCALES[locidx].getName() + ", pattern=" + PATTERNS[patidx]
                                         + ", time=" + DATES[datidx] + ", str=" + tzstr
                                         + ", outtz=" + outtzid);
                             } else {
-                                errln((UnicodeString)"Canonical round trip failed; tz=" + *tzid
+                                errln(UnicodeString("Canonical round trip failed; tz=") + *tzid
                                     + ", locale=" + LOCALES[locidx].getName() + ", pattern=" + PATTERNS[patidx]
                                     + ", time=" + DATES[datidx] + ", str=" + tzstr
                                     + ", outtz=" + outtzid);
@@ -258,7 +261,7 @@ TimeZoneFormatTest::TestTimeZoneRoundTrip() {
                     } else if (uprv_strcmp(PATTERNS[patidx], "VV") == 0) {
                         // Zone ID - full roundtrip support
                         if (outtzid != *tzid) {
-                            errln((UnicodeString)"Zone ID round trip failued; tz="  + *tzid
+                            errln(UnicodeString("Zone ID round trip failued; tz=") + *tzid
                                 + ", locale=" + LOCALES[locidx].getName() + ", pattern=" + PATTERNS[patidx]
                                 + ", time=" + DATES[datidx] + ", str=" + tzstr
                                 + ", outtz=" + outtzid);
@@ -271,19 +274,19 @@ TimeZoneFormatTest::TestTimeZoneRoundTrip() {
                         TimeZone::getCanonicalID(*tzid, canonical, status);
                         if (U_FAILURE(status)) {
                             // Unknown ID - we should not get here
-                            errln((UnicodeString)"Unknown ID " + *tzid);
+                            errln(UnicodeString("Unknown ID ") + *tzid);
                             status = U_ZERO_ERROR;
                         } else if (outtzid != canonical) {
                             // Canonical ID did not match - check the rules
                             if (!(dynamic_cast<const BasicTimeZone*>(&outtz))->hasEquivalentTransitions(dynamic_cast<BasicTimeZone&>(*tz), low, high, true, status)) {
-                                if (canonical.indexOf((char16_t)0x27 /*'/'*/) == -1) {
+                                if (canonical.indexOf(static_cast<char16_t>(0x27) /*'/'*/) == -1) {
                                     // Exceptional cases, such as CET, EET, MET and WET
-                                    logln((UnicodeString)"Canonical round trip failed (as expected); tz=" + *tzid
+                                    logln(UnicodeString("Canonical round trip failed (as expected); tz=") + *tzid
                                             + ", locale=" + LOCALES[locidx].getName() + ", pattern=" + PATTERNS[patidx]
                                             + ", time=" + DATES[datidx] + ", str=" + tzstr
                                             + ", outtz=" + outtzid);
                                 } else {
-                                    errln((UnicodeString)"Canonical round trip failed; tz=" + *tzid
+                                    errln(UnicodeString("Canonical round trip failed; tz=") + *tzid
                                         + ", locale=" + LOCALES[locidx].getName() + ", pattern=" + PATTERNS[patidx]
                                         + ", time=" + DATES[datidx] + ", str=" + tzstr
                                         + ", outtz=" + outtzid);
@@ -327,7 +330,7 @@ TimeZoneFormatTest::TestTimeZoneRoundTrip() {
                                 diff = (diff / 60000) * 60000;
                             }
                             if (diff != 0) {
-                                errln((UnicodeString)"Offset round trip failed; tz=" + *tzid
+                                errln(UnicodeString("Offset round trip failed; tz=") + *tzid
                                     + ", locale=" + LOCALES[locidx].getName() + ", pattern=" + PATTERNS[patidx]
                                     + ", time=" + DATES[datidx] + ", str=" + tzstr
                                     + ", inOffset=" + inOffset + ", outOffset=" + outOffset);
@@ -335,7 +338,7 @@ TimeZoneFormatTest::TestTimeZoneRoundTrip() {
                         } else {
                             // Specific or generic: raw offset must be preserved.
                             if (inRaw != outRaw) {
-                                errln((UnicodeString)"Raw offset round trip failed; tz=" + *tzid
+                                errln(UnicodeString("Raw offset round trip failed; tz=") + *tzid
                                     + ", locale=" + LOCALES[locidx].getName() + ", pattern=" + PATTERNS[patidx]
                                     + ", time=" + DATES[datidx] + ", str=" + tzstr
                                     + ", inRawOffset=" + inRaw + ", outRawOffset=" + outRaw);
@@ -451,7 +454,7 @@ static LocaleData *gLocaleData = nullptr;
 void
 TimeZoneFormatTest::TestTimeRoundTrip() {
     UErrorCode status = U_ZERO_ERROR;
-    LocalPointer <Calendar> cal(Calendar::createInstance(TimeZone::createTimeZone((UnicodeString) "UTC"), status));
+    LocalPointer<Calendar> cal(Calendar::createInstance(TimeZone::createTimeZone(UnicodeString("UTC")), status));
     if (U_FAILURE(status)) {
         dataerrln("Calendar::createInstance failed: %s", u_errorName(status));
         return;
@@ -519,28 +522,28 @@ TimeZoneFormatTest::TestTimeRoundTrip() {
         logln(UnicodeString("") + gLocaleData->times[i] + "ms (" + PATTERNS[i] + ")");
         total += gLocaleData->times[i];
     }
-    logln((UnicodeString) "Total: " + total + "ms");
-    logln((UnicodeString) "Iteration: " + gLocaleData->testCounts);
+    logln(UnicodeString("Total: ") + total + "ms");
+    logln(UnicodeString("Iteration: ") + gLocaleData->testCounts);
 }
 
 
 // TimeZoneFormatTest::RunTimeRoundTripTests()
 //    This function loops, running time zone format round trip test cases until there are no more, then returns.
-//    Threading: multiple invocations of this function are started in parallel 
+//    Threading: multiple invocations of this function are started in parallel
 //               by TimeZoneFormatTest::TestTimeRoundTrip()
-//    
+//
 void TimeZoneFormatTest::RunTimeRoundTripTests(int32_t threadNumber) {
     UErrorCode status = U_ZERO_ERROR;
     UBool REALLY_VERBOSE = false;
 
     // These patterns are ambiguous at DST->STD local time overlap
-    const char* AMBIGUOUS_DST_DECESSION[] = { "v", "vvvv", "V", "VV", "VVV", "VVVV", 0 };
+    const char* AMBIGUOUS_DST_DECESSION[] = { "v", "vvvv", "V", "VV", "VVV", "VVVV", nullptr };
 
     // These patterns are ambiguous at STD->STD/DST->DST local time overlap
-    const char* AMBIGUOUS_NEGATIVE_SHIFT[] = { "z", "zzzz", "v", "vvvv", "V", "VV", "VVV", "VVVV", 0 };
+    const char* AMBIGUOUS_NEGATIVE_SHIFT[] = { "z", "zzzz", "v", "vvvv", "V", "VV", "VVV", "VVVV", nullptr };
 
     // These patterns only support integer minutes offset
-    const char* MINUTES_OFFSET[] = { "X", "XX", "XXX", "x", "xx", "xxx", 0 };
+    const char* MINUTES_OFFSET[] = { "X", "XX", "XXX", "x", "xx", "xxx", nullptr };
 
     // Workaround for #6338
     //UnicodeString BASEPATTERN("yyyy-MM-dd'T'HH:mm:ss.SSS");
@@ -570,12 +573,12 @@ void TimeZoneFormatTest::RunTimeRoundTripTests(int32_t threadNumber) {
 
         UnicodeString pattern(BASEPATTERN);
         pattern.append(" ").append(PATTERNS[patidx]);
-        logln("    Thread %d, Locale %s, Pattern %s", 
+        logln("    Thread %d, Locale %s, Pattern %s",
                 threadNumber, gLocaleData->locales[locidx].getName(), CStr(pattern)());
 
         SimpleDateFormat *sdf = new SimpleDateFormat(pattern, gLocaleData->locales[locidx], status);
         if (U_FAILURE(status)) {
-            errcheckln(status, (UnicodeString) "new SimpleDateFormat failed for pattern " + 
+            errcheckln(status, UnicodeString("new SimpleDateFormat failed for pattern ") +
                 pattern + " for locale " + gLocaleData->locales[locidx].getName() + " - " + u_errorName(status));
             status = U_ZERO_ERROR;
             continue;
@@ -601,7 +604,7 @@ void TimeZoneFormatTest::RunTimeRoundTripTests(int32_t threadNumber) {
                 // Some zones are not associated with any region, such as Etc/GMT+8.
                 // The time roundtrip will fail for such zone with pattern "VVV" (exemplar location).
                 // This is expected behavior.
-                if (tzid->indexOf((char16_t)0x2F) < 0 || tzid->indexOf(ETC_SLASH, -1, 0) >= 0
+                if (tzid->indexOf(static_cast<char16_t>(0x2F)) < 0 || tzid->indexOf(ETC_SLASH, -1, 0) >= 0
                     || tzid->indexOf(SYSTEMV_SLASH, -1, 0) >= 0 || tzid->indexOf(RIYADH8, -1, 0) >= 0) {
                     continue;
                 }
@@ -616,6 +619,7 @@ void TimeZoneFormatTest::RunTimeRoundTripTests(int32_t threadNumber) {
             BasicTimeZone *tz = dynamic_cast<BasicTimeZone*>(TimeZone::createTimeZone(*tzid));
             sdf->setTimeZone(*tz);
 
+
             UDate t = gLocaleData->START_TIME;
             TimeZoneTransition tzt;
             UBool tztAvail = false;
@@ -672,24 +676,24 @@ void TimeZoneFormatTest::RunTimeRoundTripTests(int32_t threadNumber) {
 
                     UDate parsedDate = sdf->parse(text, status);
                     if (U_FAILURE(status)) {
-                        errln((UnicodeString) "Parse failure for text=" + text + ", tzid=" + *tzid + ", locale=" + gLocaleData->locales[locidx].getName()
+                        errln(UnicodeString("Parse failure for text=") + text + ", tzid=" + *tzid + ", locale=" + gLocaleData->locales[locidx].getName()
                                 + ", pattern=" + PATTERNS[patidx] + ", time=" + testTimes[testidx]);
                         status = U_ZERO_ERROR;
                         continue;
                     }
 
-                    int32_t timeDiff = (int32_t)(parsedDate - testTimes[testidx]);
+                    int32_t timeDiff = static_cast<int32_t>(parsedDate - testTimes[testidx]);
                     UBool bTimeMatch = minutesOffset ?
                         (timeDiff/60000)*60000 == 0 : timeDiff == 0;
                     if (!bTimeMatch) {
-                        UnicodeString msg = (UnicodeString) "Time round trip failed for " + "tzid=" + *tzid
+                        UnicodeString msg = UnicodeString("Time round trip failed for ") + "tzid=" + *tzid
                                 + ", locale=" + gLocaleData->locales[locidx].getName() + ", pattern=" + PATTERNS[patidx]
                                 + ", text=" + text + ", time=" + testTimes[testidx] + ", restime=" + parsedDate + ", diff=" + (parsedDate - testTimes[testidx]);
                         // Timebomb for TZData update
                         if (expectedRoundTrip[testidx]
                                 && !isSpecialTimeRoundTripCase(gLocaleData->locales[locidx].getName(), *tzid,
                                         PATTERNS[patidx], testTimes[testidx])) {
-                            errln((UnicodeString) "FAIL: " + msg);
+                            errln(UnicodeString("FAIL: ") + msg);
                         } else if (REALLY_VERBOSE) {
                             logln(msg);
                         }
@@ -701,7 +705,7 @@ void TimeZoneFormatTest::RunTimeRoundTripTests(int32_t threadNumber) {
                 }
                 if (middle) {
                     // Test the date in the middle of two transitions.
-                    t += (int64_t) ((tzt.getTime() - t) / 2);
+                    t += static_cast<int64_t>((tzt.getTime() - t) / 2);
                     middle = false;
                     tztAvail = false;
                 } else {
@@ -879,20 +883,20 @@ TimeZoneFormatTest::TestParse() {
             UnicodeString outID;
             tz->getID(outID);
             if (outID != UnicodeString(DATA[i].expected)) {
-                errMsg = (UnicodeString)"Time zone ID: " + outID + " - expected: " + DATA[i].expected;
+                errMsg = UnicodeString("Time zone ID: ") + outID + " - expected: " + DATA[i].expected;
             } else if (pos.getIndex() != DATA[i].outPos) {
-                errMsg = (UnicodeString)"Parsed pos: " + pos.getIndex() + " - expected: " + DATA[i].outPos;
+                errMsg = UnicodeString("Parsed pos: ") + pos.getIndex() + " - expected: " + DATA[i].outPos;
             } else if (ttype != DATA[i].timeType) {
-                errMsg = (UnicodeString)"Time type: " + ttype + " - expected: " + DATA[i].timeType;
+                errMsg = UnicodeString("Time type: ") + ttype + " - expected: " + DATA[i].timeType;
             }
             delete tz;
         } else {
             if (DATA[i].expected) {
-                errMsg = (UnicodeString)"Parse failure - expected: " + DATA[i].expected;
+                errMsg = UnicodeString("Parse failure - expected: ") + DATA[i].expected;
             }
         }
         if (errMsg.length() > 0) {
-            errln((UnicodeString)"Fail: " + errMsg + " [text=" + DATA[i].text + ", pos=" + DATA[i].inPos + ", style=" + DATA[i].style + "]");
+            errln(UnicodeString("Fail: ") + errMsg + " [text=" + DATA[i].text + ", pos=" + DATA[i].inPos + ", style=" + DATA[i].style + "]");
         }
     }
 }
@@ -976,9 +980,9 @@ TimeZoneFormatTest::TestISOFormat() {
         },
         // 108000000
         {
-            0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0,
-            0
+            nullptr, nullptr, nullptr, nullptr, nullptr,
+            nullptr, nullptr, nullptr, nullptr, nullptr,
+            nullptr
         }
     };
 
@@ -986,7 +990,7 @@ TimeZoneFormatTest::TestISOFormat() {
         "X", "XX", "XXX", "XXXX", "XXXXX",
         "x", "xx", "xxx", "xxxx", "xxxxx",
         "Z", // equivalent to "xxxx"
-        0
+        nullptr
     };
 
     const int32_t MIN_OFFSET_UNIT[] = {
@@ -1007,14 +1011,14 @@ TimeZoneFormatTest::TestISOFormat() {
     for (uint32_t i = 0; i < UPRV_LENGTHOF(OFFSET); i++) {
         SimpleTimeZone* tz = new SimpleTimeZone(OFFSET[i], UnicodeString("Zone Offset:") + OFFSET[i] + "ms");
         sdf->adoptTimeZone(tz);
-        for (int32_t j = 0; PATTERN[j] != 0; j++) {
+        for (int32_t j = 0; PATTERN[j] != nullptr; j++) {
             sdf->applyPattern(UnicodeString(PATTERN[j]));
             UnicodeString result;
             sdf->format(d, result);
 
             if (ISO_STR[i][j]) {
                 if (result != UnicodeString(ISO_STR[i][j])) {
-                    errln((UnicodeString)"FAIL: pattern=" + PATTERN[j] + ", offset=" + OFFSET[i] + " -> "
+                    errln(UnicodeString("FAIL: pattern=") + PATTERN[j] + ", offset=" + OFFSET[i] + " -> "
                         + result + " (expected: " + ISO_STR[i][j] + ")");
                 }
             } else {
@@ -1022,7 +1026,7 @@ TimeZoneFormatTest::TestISOFormat() {
                 // Note: for now, there is no way to propagate the error status through
                 // the SimpleDateFormat::format above.
                 if (result.length() > 0) {
-                    errln((UnicodeString)"FAIL: Non-Empty result for pattern=" + PATTERN[j] + ", offset=" + OFFSET[i]
+                    errln(UnicodeString("FAIL: Non-Empty result for pattern=") + PATTERN[j] + ", offset=" + OFFSET[i]
                         + " (expected: empty result)");
                 }
             }
@@ -1036,8 +1040,8 @@ TimeZoneFormatTest::TestISOFormat() {
         return;
     }
     for (int32_t i = 0; ISO_STR[i][0] != nullptr; i++) {
-        for (int32_t j = 0; PATTERN[j] != 0; j++) {
-            if (ISO_STR[i][j] == 0) {
+        for (int32_t j = 0; PATTERN[j] != nullptr; j++) {
+            if (ISO_STR[i][j] == nullptr) {
                 continue;
             }
             ParsePosition pos(0);
@@ -1047,15 +1051,15 @@ TimeZoneFormatTest::TestISOFormat() {
 
             sdf->parse(UnicodeString(ISO_STR[i][j]), *(outcal.getAlias()), pos);
 
-            if (pos.getIndex() != (int32_t)uprv_strlen(ISO_STR[i][j])) {
-                errln((UnicodeString)"FAIL: Failed to parse the entire input string: " + ISO_STR[i][j]);
+            if (pos.getIndex() != static_cast<int32_t>(uprv_strlen(ISO_STR[i][j]))) {
+                errln(UnicodeString("FAIL: Failed to parse the entire input string: ") + ISO_STR[i][j]);
             }
 
             const TimeZone& outtz = outcal->getTimeZone();
             int32_t outOffset = outtz.getRawOffset();
             int32_t adjustedOffset = OFFSET[i] / MIN_OFFSET_UNIT[j] * MIN_OFFSET_UNIT[j];
             if (outOffset != adjustedOffset) {
-                errln((UnicodeString)"FAIL: Incorrect offset:" + outOffset + "ms for input string: " + ISO_STR[i][j]
+                errln(UnicodeString("FAIL: Incorrect offset:") + outOffset + "ms for input string: " + ISO_STR[i][j]
                     + " (expected:" + adjustedOffset + "ms)");
             }
         }
@@ -1080,7 +1084,7 @@ TimeZoneFormatTest::TestFormat() {
     const FormatTestData DATA[] = {
         {
             "en",
-            "America/Los_Angeles", 
+            "America/Los_Angeles",
             dateJan,
             UTZFMT_STYLE_GENERIC_LOCATION,
             "Los Angeles Time",
@@ -1144,7 +1148,7 @@ TimeZoneFormatTest::TestFormat() {
             UTZFMT_TIME_TYPE_UNKNOWN
         },
 
-        {0, 0, 0.0, UTZFMT_STYLE_GENERIC_LOCATION, 0, UTZFMT_TIME_TYPE_UNKNOWN}
+        {nullptr, nullptr, 0.0, UTZFMT_STYLE_GENERIC_LOCATION, nullptr, UTZFMT_TIME_TYPE_UNKNOWN}
     };
 
     for (int32_t i = 0; DATA[i].locale; i++) {
@@ -1179,7 +1183,7 @@ TimeZoneFormatTest::TestFormatTZDBNames() {
     const FormatTestData DATA[] = {
         {
             "en",
-            "America/Chicago", 
+            "America/Chicago",
             dateJan,
             UTZFMT_STYLE_SPECIFIC_SHORT,
             "CST",
@@ -1187,7 +1191,7 @@ TimeZoneFormatTest::TestFormatTZDBNames() {
         },
         {
             "en",
-            "Asia/Shanghai", 
+            "Asia/Shanghai",
             dateJan,
             UTZFMT_STYLE_SPECIFIC_SHORT,
             "CST",
@@ -1195,7 +1199,7 @@ TimeZoneFormatTest::TestFormatTZDBNames() {
         },
         {
             "zh_Hans",
-            "Asia/Shanghai", 
+            "Asia/Shanghai",
             dateJan,
             UTZFMT_STYLE_SPECIFIC_SHORT,
             "CST",
@@ -1234,7 +1238,7 @@ TimeZoneFormatTest::TestFormatTZDBNames() {
             UTZFMT_TIME_TYPE_STANDARD
         },
 
-        {0, 0, 0.0, UTZFMT_STYLE_GENERIC_LOCATION, 0, UTZFMT_TIME_TYPE_UNKNOWN}
+        {nullptr, nullptr, 0.0, UTZFMT_STYLE_GENERIC_LOCATION, nullptr, UTZFMT_TIME_TYPE_UNKNOWN}
     };
 
     for (int32_t i = 0; DATA[i].locale; i++) {
@@ -1278,14 +1282,14 @@ TimeZoneFormatTest::TestFormatCustomZone() {
         { "abc", 3600000, "GMT+01:00" },                    // unknown ID
         { "$abc", -3600000, "GMT-01:00" },                 // unknown, with ASCII variant char '$'
         { "\\u00c1\\u00df\\u00c7", 5400000, "GMT+01:30"},    // unknown, with non-ASCII chars
-        { 0, 0, 0 }
+        { nullptr, 0, nullptr }
     };
 
     UDate now = Calendar::getNow();
 
     for (int32_t i = 0; ; i++) {
         const char *id = TESTDATA[i].id;
-        if (id == 0) {
+        if (id == nullptr) {
             break;
         }
         UnicodeString tzid = UnicodeString(id, -1, US_INV).unescape();
@@ -1305,6 +1309,63 @@ TimeZoneFormatTest::TestFormatCustomZone() {
     }
 }
 
+void
+TimeZoneFormatTest::Test22615NonASCIIID() {
+    UErrorCode status = U_ZERO_ERROR;
+    LocalPointer<TimeZoneNames> tzdb(TimeZoneNames::createTZDBInstance(Locale("en"), status));
+    // A test to ensure under the debugging build non ASCII id will not cause
+    // internal assertion error.
+    UnicodeString id(9, u'\u00C0', 8);
+    UnicodeString output;
+    tzdb->getMetaZoneDisplayName(id, UTZNM_SHORT_STANDARD, output);
+    assertTrue("getMetaZoneID of non ASCII id should return bogus string",
+               output.isBogus());
+
+    status = U_ZERO_ERROR;
+    std::unique_ptr<icu::StringEnumeration> enumeration(
+        tzdb->getAvailableMetaZoneIDs(id, status));
+    assertSuccess("getAvailableMetaZoneIDs should success", status);
+    assertEquals("getAvailableMetaZoneIDs with non ASCII id return 0 ids",
+                 0, enumeration->count(status));
+    assertSuccess("count should success", status);
+
+    output.remove();
+    tzdb->getMetaZoneID(id, 0, output);
+    assertTrue("getMetaZoneID of non ASCII id should return bogus string",
+               output.isBogus());
+
+    output.remove();
+    tzdb->getMetaZoneDisplayName(id, UTZNM_EXEMPLAR_LOCATION, output);
+    assertTrue("getMetaZoneDisplayName of non ASCII id should return bogus string",
+               output.isBogus());
+
+    output.remove();
+    tzdb->getTimeZoneDisplayName(id, UTZNM_SHORT_DAYLIGHT, output);
+    assertTrue("getTimeZoneDisplayName of non ASCII id should return bogus string",
+               output.isBogus());
+
+    output.remove();
+    tzdb->getExemplarLocationName(id, output);
+    assertTrue("getExemplarLocationName of non ASCII id should return bogus string",
+               output.isBogus());
+
+    output.remove();
+    tzdb->getDisplayName(id, UTZNM_LONG_GENERIC, 0, output);
+    assertTrue("getDisplayName of non ASCII id should return bogus string",
+               output.isBogus());
+}
+
+void
+TimeZoneFormatTest::Test22614GetMetaZoneNamesNotCrash() {
+    UErrorCode status = U_ZERO_ERROR;
+    LocalPointer<TimeZoneNames> tzdbNames(TimeZoneNames::createTZDBInstance(Locale("en"), status));
+    UnicodeString name;
+    for (int32_t i = 124; i < 150; i++) {
+        name.remove();
+        UnicodeString mzId(i+1, u'A', i);
+        tzdbNames->getMetaZoneDisplayName(mzId, UTZNM_SHORT_STANDARD, name);
+    }
+}
 void
 TimeZoneFormatTest::TestFormatTZDBNamesAllZoneCoverage() {
     UErrorCode status = U_ZERO_ERROR;
@@ -1323,28 +1384,28 @@ TimeZoneFormatTest::TestFormatTZDBNamesAllZoneCoverage() {
         LocalPointer<TimeZone> tz(TimeZone::createTimeZone(*tzid));
         tzdbNames->getMetaZoneID(*tzid, now, mzId);
         if (mzId.isBogus()) {
-            logln((UnicodeString)"Meta zone: <not available>");
+            logln(UnicodeString("Meta zone: <not available>"));
         } else {
-            logln((UnicodeString)"Meta zone: " + mzId);
+            logln(UnicodeString("Meta zone: ") + mzId);
         }
 
         // mzID could be bogus here
         tzdbNames->getMetaZoneDisplayName(mzId, UTZNM_SHORT_STANDARD, name);
         // name could be bogus here
         if (name.isBogus()) {
-            logln((UnicodeString)"Meta zone short standard name: <not available>");
+            logln(UnicodeString("Meta zone short standard name: <not available>"));
         }
         else {
-            logln((UnicodeString)"Meta zone short standard name: " + name);
+            logln(UnicodeString("Meta zone short standard name: ") + name);
         }
 
         tzdbNames->getMetaZoneDisplayName(mzId, UTZNM_SHORT_DAYLIGHT, name);
         // name could be bogus here
         if (name.isBogus()) {
-            logln((UnicodeString)"Meta zone short daylight name: <not available>");
+            logln(UnicodeString("Meta zone short daylight name: <not available>"));
         }
         else {
-            logln((UnicodeString)"Meta zone short daylight name: " + name);
+            logln(UnicodeString("Meta zone short daylight name: ") + name);
         }
     }
 }
@@ -1392,13 +1453,23 @@ TimeZoneFormatTest::TestCentralTime() {
         UDate dBZ = sdfBZ.parse(testInputs[i], status);
 
         if (U_FAILURE(status)) {
-            errln((UnicodeString)"Failed to parse date string: " + testInputs[i]);
+            errln(UnicodeString("Failed to parse date string: ") + testInputs[i]);
             continue;
         }
 
         if (dUS != dBZ) {
-            errln((UnicodeString)"Parse results should be same for input: " + testInputs[i]);
+            errln(UnicodeString("Parse results should be same for input: ") + testInputs[i]);
         }
     }
 }
+void
+TimeZoneFormatTest::TestBogusLocale() {
+    Locale bogus("not a lang");
+    UErrorCode status = U_ZERO_ERROR;
+    std::unique_ptr<icu::TimeZoneFormat> tzfmt(
+        icu::TimeZoneFormat::createInstance(bogus, status));
+    if (U_FAILURE(status)) {
+        errln(u"Failed to createInstance with bogus locale");
+    }
+}
 #endif /* #if !UCONFIG_NO_FORMATTING */
