@@ -29,7 +29,7 @@ public:
   UCAConformanceTest();
   virtual ~UCAConformanceTest();
 
-  void runIndexedTest( int32_t index, UBool exec, const char* &name, char* /*par = NULL */) override;
+  void runIndexedTest( int32_t index, UBool exec, const char* &name, char* /*par = nullptr */) override;
 
   void TestTableNonIgnorable(/* par */);
   void TestTableShifted(/* par */);     
